pub enum OmenaResolverBoundaryTopV0 {
TopOpaque,
TopAny,
}Expand description
Abstract value top used when a boundary is not fully resolved.
Variants
TopOpaque
The interface is known enough to keep diagnostics scoped to declared exported symbols.
TopAny
The interface is unknown and diagnostics must avoid false positives over potentially valid external symbols.
Implementations